@@ -5,7 +5,7 @@
 #' These functions are based on \code{\link{update.packages}}.  However, rather than looking for locally installed packages they look for the package source and binaries in the miniCRAN repository.
 #'
 #' @name updatePackages
-#' 
+#'
 #' @inheritParams makeRepo
 #' @inheritParams pkgDep
 #'
@@ -22,10 +22,10 @@
 #'
 #' @example /inst/examples/example_updatePackages.R
 #'
-oldPackages <- function (path = NULL, 
+oldPackages <- function (path = NULL,
                          repos = getOption("repos"),
                          availPkgs = pkgAvail(repos=repos, type=type, Rversion=Rversion),
-                         method, 
+                         method,
                          availableLocal = pkgAvail(repos=path, type=type, Rversion=Rversion), type="source",
                          Rversion = R.version) {
   if (is.null(path)) stop("path to miniCRAN repo must be specified")
@@ -35,7 +35,7 @@ oldPackages <- function (path = NULL,
   }
   if (NROW(availPkgs) == 0L) stop("Invalid remote repository")
   if (NROW(availableLocal) == 0L) stop("Invalid local repository")
-  
+
   idx <- match(availableLocal[, "Package"], availPkgs[, "Package"])
   compare <- sapply(seq_along(idx), function(i){
     compareVersion(
@@ -43,7 +43,7 @@ oldPackages <- function (path = NULL,
       (availableLocal[i, "Version"])
     ) > 0
   })
-  
+
   update <- cbind(
     availableLocal[compare, c("Package", "Version"), drop=FALSE],
     availPkgs[idx[compare], c("Version", "Repository"), drop=FALSE]
@@ -66,72 +66,74 @@ oldPackages <- function (path = NULL,
 #' @export
 #'
 updatePackages <- function (path=NULL, repos=getOption("repos"),
-                            method, ask=TRUE, 
+                            method, ask=TRUE,
                             availPkgs=pkgAvail(repos=repos, type=type, Rversion=Rversion),
                             oldPkgs=NULL, type="source",
                             Rversion=R.version,
                             quiet=FALSE) {
-  force(ask)
-  simplifyRepos <- function(repos, type) {
-    tail <- substring(contribUrl("---", type=type, Rversion=Rversion), 4)
-    ind <- regexpr(tail, repos, fixed=TRUE)
-    ind <- ifelse(ind > 0, ind-1, nchar(repos, type="c"))
-    substr(repos, 1, ind)
-  }
-  text.select <- function(old) {
-    update <- NULL
-    for (k in seq_len(nrow(old))) {
-      cat(old[k, "Package"], ":\n",
-          "Local Version", old[k, "LocalVer"], "\n",
-          "Repos Version", old[k, "ReposVer"],
-          "available at", simplifyRepos(old[k, "Repository"], type))
-      cat("\n")
-      answer <- substr(readline("Update (y/N/c)?  "), 1L, 1L)
-      if (answer == "c" | answer == "C") {
-        cat("cancelled by user\n")
+  lapply(type, function(t) {
+    force(ask)
+    simplifyRepos <- function(repos, t) {
+      tail <- substring(contribUrl("---", type=t, Rversion=Rversion), 4)
+      ind <- regexpr(tail, repos, fixed=TRUE)
+      ind <- ifelse(ind > 0, ind-1, nchar(repos, type="c"))
+      substr(repos, 1, ind)
+    }
+    text.select <- function(old) {
+      update <- NULL
+      for (k in seq_len(nrow(old))) {
+        cat(old[k, "Package"], ":\n",
+            "Local Version", old[k, "LocalVer"], "\n",
+            "Repos Version", old[k, "ReposVer"],
+            "available at", simplifyRepos(old[k, "Repository"], t))
+        cat("\n")
+        answer <- substr(readline("Update (y/N/c)?  "), 1L, 1L)
+        if (answer == "c" | answer == "C") {
+          cat("cancelled by user\n")
+          return(invisible())
+        }
+        if (answer == "y" | answer == "Y") update <- rbind(update, old[k, ])
+      }
+      update
+    }
+    if (is.null(path)) stop("path to miniCRAN repo must be specified")
+    if (!is.matrix(oldPkgs) && is.character(oldPkgs)) {
+      subset <- oldPkgs
+      oldPkgs <- NULL
+    } else {
+      subset <- NULL
+    }
+    if (is.null(oldPkgs)) {
+      oldPkgs <- oldPackages(path=path, repos=repos,
+                             method=method, availPkgs=availPkgs, type=t,
+                             Rversion=Rversion)
+      if (is.null(oldPkgs)) {
+        message("All packages are up to date from repos: ", names(repos))
         return(invisible())
       }
-      if (answer == "y" | answer == "Y") update <- rbind(update, old[k, ])
+    } else if (!(is.matrix(oldPkgs) && is.character(oldPkgs))) {
+      stop("invalid 'oldPkgs'; must be a character vector or a result from oldPackages()")
     }
-    update
-  }
-  if (is.null(path)) stop("path to miniCRAN repo must be specified")
-  if (!is.matrix(oldPkgs) && is.character(oldPkgs)) {
-    subset <- oldPkgs
-    oldPkgs <- NULL
-  } else {
-    subset <- NULL
-  }
-  if (is.null(oldPkgs)) {
-    oldPkgs <- oldPackages(path=path, repos=repos, 
-                           method=method, availPkgs=availPkgs, type=type,
-                           Rversion=Rversion)
-    if (is.null(oldPkgs)) {
-      message("All packages are up to date from repos: ", names(repos))
-      return(invisible())
+    if (!is.null(subset)) {
+      oldPkgs <- oldPkgs[rownames(oldPkgs) %in% subset, , drop = FALSE]
+      if (nrow(oldPkgs)==0) return(invisible())
     }
-  } else if (!(is.matrix(oldPkgs) && is.character(oldPkgs))) {
-    stop("invalid 'oldPkgs'; must be a character vector or a result from oldPackages()")
-  }
-  if (!is.null(subset)) {
-    oldPkgs <- oldPkgs[rownames(oldPkgs) %in% subset, , drop = FALSE]
-    if (nrow(oldPkgs)==0) return(invisible())
-  }
-  update <- if (is.character(ask) && ask == "graphics") {
-    if (.Platform$OS.type=="windows" || .Platform$GUI ==
-          "AQUA" || (capabilities("tcltk") && capabilities("X11"))) {
-      k <- select.list(oldPkgs[, 1L], oldPkgs[, 1L], multiple=TRUE,
-                       title="Packages to be updated", graphics = TRUE)
-      oldPkgs[match(k, oldPkgs[, 1L]), , drop = FALSE]
-    } else {
+    update <- if (is.character(ask) && ask == "graphics") {
+      if (.Platform$OS.type=="windows" || .Platform$GUI ==
+            "AQUA" || (capabilities("tcltk") && capabilities("X11"))) {
+        k <- select.list(oldPkgs[, 1L], oldPkgs[, 1L], multiple=TRUE,
+                         title="Packages to be updated", graphics = TRUE)
+        oldPkgs[match(k, oldPkgs[, 1L]), , drop = FALSE]
+      } else {
+        text.select(oldPkgs)
+      }
+    } else if (isTRUE(ask)) {
       text.select(oldPkgs)
+    } else {
+      oldPkgs
     }
-  } else if (isTRUE(ask)) {
-    text.select(oldPkgs)
-  } else {
-    oldPkgs
-  }
-  if (length(update[,"Package"])) {
-    addPackage(update[,"Package"], path=path, repos=repos, type=type, quiet=quiet, deps=FALSE, Rversion=Rversion)
-  }
+    if (length(update[,"Package"])) {
+      addPackage(update[,"Package"], path=path, repos=repos, type=t, quiet=quiet, deps=FALSE, Rversion=Rversion)
+    }
+  })
 }
