@@ -5,7 +5,7 @@ availPkgs <- cranJuly2014
 
 \dontrun{
 availPkgs <- pkgAvail(
-  repos = c(CRAN="http://cran.revolutionanalytics.com"),
+  repos = c(CRAN="http://mran.microsoft.com"),
   type="source"
   )
 }
@@ -26,7 +26,7 @@ if(require(igraph)) plot(p)
   
   p <- makeDepGraph(
   c("ggplot2", "forecast"), 
-  repos = c(CRAN="http://cran.revolutionanalytics.com"), 
+  repos = c(CRAN = "http://mran.microsoft.com"), 
   type="source"
 )
 if(require(igraph)) plot(p)
