@@ -1,4 +1,4 @@
-if(interactive()) {library(testthat); Sys.setenv(NOT_CRAN="true")}
+if (interactive()) {library(testthat); Sys.setenv(NOT_CRAN = "true")}
 
 context("updateRepo")
 
@@ -6,52 +6,56 @@ context("updateRepo")
 
 
 repo_root <- file.path(tempdir(), "miniCRAN", Sys.Date())
-if(file.exists(repo_root)) unlink(repo_root, recursive=TRUE)
-dir.create(repo_root, recursive=TRUE, showWarnings=FALSE)
+if (file.exists(repo_root)) unlink(repo_root, recursive = TRUE)
+dir.create(repo_root, recursive = TRUE, showWarnings = FALSE)
 
 revolution <- MRAN("2014-10-15")
+if(!miniCRAN:::is.online(revolution, tryHttp = FALSE)) {
+  # Use http:// for older versions of R
+  revolution <- sub("^https://", "http://", revolution)
+}
+rvers <- "3.1"
 pkgs <- c("chron", "adaptivetau")
 
 types <- c("source", "win.binary", "mac.binary")
 names(types) <- types
 
-
 test_that("sample repo is setup correctly", {
   skip_if_offline(revolution)
-  
-  pdb <<- lapply(types, pkgAvail, repos=revolution, Rversion = "3.1")
-  pkgList <<- lapply(types, function(type){
-    pkgDep(pkg=pkgs, type=types[type], availPkgs=pdb[[type]], repos=revolution, suggests=FALSE, Rversion = "3.1")
+
+  pdb <<- lapply(types, pkgAvail, repos = revolution, Rversion = rvers)
+  pkgList <<- lapply(types, function(type) {
+    pkgDep(pkg = pkgs, type = types[type], availPkgs = pdb[[type]],
+           repos = revolution, suggests = FALSE, Rversion = rvers)
   })
-  
-  miniCRAN:::.createSampleRepo(path = repo_root, MRAN = revolution, Rversion = "3.1")
+
+  miniCRAN:::.createSampleRepo(path = repo_root, MRAN = revolution, Rversion = rvers)
   expect_equal(unname(pkgAvail(repo_root)[, "Package"]), sort(pkgs))
 })
 
 
-
-
 # Add packages to repo ----------------------------------------------------
 
 pkgsAdd <- c("aprof")
 
-for(pkg_type in names(types)){
+for (pkg_type in names(types)) {
 
   context(sprintf(" - Add packages to repo (%s)", pkg_type))
-  
+
   test_that(sprintf("addPackage downloads %s files and rebuilds PACKAGES file", pkg_type), {
 
     skip_on_cran()
     skip_if_offline(revolution)
-    
-    pkgListAdd <- pkgDep(pkgsAdd, availPkgs=pdb[[pkg_type]], 
-                         repos = revolution, 
-                         type  = pkg_type, 
-                         suggests = FALSE, 
-                         Rversion = "3.1")
-    prefix <- miniCRAN:::repoPrefix(pkg_type, Rversion = "3.1")
 
-    addPackage(pkgListAdd, path=repo_root, repos=revolution, type=pkg_type, quiet=TRUE, Rversion = "3.1")
+    pkgListAdd <- pkgDep(pkgsAdd, availPkgs = pdb[[pkg_type]],
+                         repos = revolution,
+                         type  = pkg_type,
+                         suggests = FALSE,
+                         Rversion = rvers)
+    prefix <- miniCRAN:::repoPrefix(pkg_type, Rversion = rvers)
+
+    addPackage(pkgListAdd, path = repo_root, repos = revolution, type = pkg_type,
+               quiet = TRUE, Rversion = rvers)
 
     expect_true(
       miniCRAN:::.checkForRepoFiles(repo_root, pkgListAdd, prefix)
@@ -61,12 +65,10 @@ for(pkg_type in names(types)){
     )
     expect_true(
       all(
-        pkgListAdd %in% pkgAvail(repo_root, type=pkg_type, Rversion = "3.1")[, "Package"]
+        pkgListAdd %in% pkgAvail(repo_root, type = pkg_type, Rversion = rvers)[, "Package"]
       )
     )
-
   })
-
 }
 
 
@@ -75,26 +77,29 @@ for(pkg_type in names(types)){
 
 
 MRAN_mirror <- MRAN("2014-12-01")
+if(!miniCRAN:::is.online(MRAN_mirror, tryHttp = FALSE)) {
+  # Use http:// for older versions of R
+  MRAN_mirror <- sub("^https://", "http://", revolution)
+}
 
-
-for(pkg_type in names(types)){
-  
+for (pkg_type in names(types)) {
   context(sprintf(" - Check for updates (%s)", pkg_type))
-  
+
   test_that(sprintf("updatePackages downloads %s files and builds PACKAGES file", pkg_type), {
 
     skip_on_cran()
     skip_if_offline(MRAN_mirror)
 
-    prefix <- miniCRAN:::repoPrefix(pkg_type, Rversion = "3.1")
+    prefix <- miniCRAN:::repoPrefix(pkg_type, Rversion = rvers)
 
-    old <- oldPackages(path=repo_root, repos=MRAN_mirror, type=pkg_type, Rversion = "3.1")
+    old <- oldPackages(path = repo_root, repos = MRAN_mirror, type = pkg_type, Rversion = rvers)
 
     expect_equal(nrow(old), 2)
     expect_equal(ncol(old), 4)
     expect_equal(rownames(old), c("adaptivetau", "aprof"))
 
-    updatePackages(path=repo_root, repos=MRAN_mirror, type=pkg_type, ask=FALSE, quiet=TRUE, Rversion = "3.1")
+    updatePackages(path = repo_root, repos = MRAN_mirror, type = pkg_type,
+                   ask = FALSE, quiet = TRUE, Rversion = rvers)
 
     updateVers <- miniCRAN:::getPkgVersFromFile(list.files(file.path(repo_root, prefix)))
 
@@ -106,7 +111,7 @@ for(pkg_type in names(types)){
       file.exists(file.path(repo_root, prefix, "PACKAGES.gz"))
     )
 
-    old <- oldPackages(path=repo_root, repos=MRAN_mirror, type=pkg_type, Rversion = "3.1")
+    old <- oldPackages(path = repo_root, repos = MRAN_mirror, type = pkg_type, Rversion = rvers)
     # browser()
     expect_equal(nrow(old), 0)
     expect_equal(ncol(old), 4)
@@ -119,26 +124,26 @@ for(pkg_type in names(types)){
 
 context("Check for duplicate files")
 
-for(pkg_type in names(types)){
+for (pkg_type in names(types)) {
 
   test_that(sprintf("checkVersions() finds out-of-date %s packages", pkg_type), {
 
     skip_on_cran()
     skip_if_offline(MRAN_mirror)
 
-    oldVersions <- list(package=c("aprof"),
-                        version=c("0.2.1"))
-    if(pkg_type != "source"){
+    oldVersions <- list(package = c("aprof"),
+                        version = c("0.2.1"))
+    if (pkg_type != "source") {
       expect_error(
-        addOldPackage(oldVersions[["package"]], path=repo_root, vers=oldVersions[["version"]],
-                      repos=MRAN_mirror, type=pkg_type)
+        addOldPackage(oldVersions[["package"]], path = repo_root, vers = oldVersions[["version"]],
+                      repos = MRAN_mirror, type = pkg_type)
       )
     } else {
-      addOldPackage(oldVersions[["package"]], path=repo_root, vers=oldVersions[["version"]],
-                    repos=MRAN_mirror, type=pkg_type)
+      addOldPackage(oldVersions[["package"]], path = repo_root, vers = oldVersions[["version"]],
+                    repos = MRAN_mirror, type = pkg_type)
       files <- suppressWarnings(
-        checkVersions(path=repo_root, type=pkg_type)
-        )
+        checkVersions(path = repo_root, type = pkg_type)
+      )
 
       expect_true(
         all(file.exists(files))
@@ -151,6 +156,5 @@ for(pkg_type in names(types)){
       )
 
     }
-
   })
 }
